@@ -3,7 +3,7 @@ import httplib
 import re
 import logging
 
-from oscar.apps.payment.exceptions import GatewayError
+from oscar.apps.payment.exceptions import GatewayError 
 
 logger = logging.getLogger('datacash')
 
@@ -182,8 +182,8 @@ class Gateway(object):
                 self._create_element(doc, cv2avs, 'street_address%d' % n, kwargs[key])
         if 'postcode' in kwargs:
             self._create_element(doc, cv2avs, 'postcode', kwargs['postcode'])
-        if 'ccv' in kwargs:
-            self._create_element(doc, cv2avs, 'cv2', kwargs['ccv'])
+        if 'cvv' in kwargs:
+            self._create_element(doc, cv2avs, 'cv2', kwargs['cvv'])
 
     def _create_element(self, doc, parent, tag, value=None, attributes=None):
         """
@@ -204,6 +204,8 @@ class Gateway(object):
                 raise ValueError('You must provide a "%s" argument' % key)
         for key in kwargs:
             value = kwargs[key]
+            if key == 'amount' and value == 0:
+                raise ValueError('Amount must be non-zero')
             if key in ('expiry_date', 'start_date') and not re.match(r'^\d{2}/\d{2}$', value):
                 raise ValueError("%s not in format dd/yy" % key)
             if key == 'issue_number' and not re.match(r'^\d{1,2}$', kwargs[key]):
